ploneintranet.core.tests package
================================

Submodules
----------

ploneintranet.core.tests.test_installed module
----------------------------------------------

.. automodule:: ploneintranet.core.tests.test_installed
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ploneintranet.core.tests
    :members:
    :undoc-members:
    :show-inheritance:
